==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Effect/ladspa/translations/ladspa_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>EffectLADSPAFactory</name>
    <message>
        <location filename="../effectladspafactory.cpp" line="31"/>
        <source>LADSPA Plugin</source>
        <translation>Plugin LADSPA</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="51"/>
        <source>About LADSPA Host for Qmmp</source>
        <translation>Tentang Host LADSPA bagi Qmmp</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="52"/>
        <source>LADSPA Host for Qmmp</source>
        <translation>Host LADSPA bagi Qmmp</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="54"/>
        <source>Based on the LADSPA Host for BMP</source>
        <translation>Berdasarkan pada Host LADSPA bagi BMP</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="55"/>
        <source>BMP-ladspa developers:</source>
        <translation>Pengembang BMP-ladspa:</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="56"/>
        <source>Nick Lamb &lt;njl195@zepler.org.uk&gt;</source>
        <translation>Nick Lamb &lt;njl195@zepler.org.uk&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="57"/>
        <source>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</source>
        <translation>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>LADSPA Plugin Catalog</source>
        <translation>Katalog Plugin LADSPA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Configure</source>
        <translation>Tata</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>This LADSPA plugin has no user controls</source>
        <translation>Plugin LADSPA ini tidak memiliki kendali pengguna</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Effect/ladspa/translations/ladspa_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>EffectLADSPAFactory</name>
    <message>
        <location filename="../effectladspafactory.cpp" line="31"/>
        <source>LADSPA Plugin</source>
        <translation>Plugin LADSPA</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="51"/>
        <source>About LADSPA Host for Qmmp</source>
        <translation>Tentang Host LADSPA bagi Qmmp</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="52"/>
        <source>LADSPA Host for Qmmp</source>
        <translation>Host LADSPA bagi Qmmp</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="54"/>
        <source>Based on the LADSPA Host for BMP</source>
        <translation>Berdasarkan pada Host LADSPA bagi BMP</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="55"/>
        <source>BMP-ladspa developers:</source>
        <translation>Pengembang BMP-ladspa:</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="56"/>
        <source>Nick Lamb &lt;njl195@zepler.org.uk&gt;</source>
        <translation>Nick Lamb &lt;njl195@zepler.org.uk&gt;</translation>
    </message>
    <message>
        <location filename="../effectladspafactory.cpp" line="57"/>
        <source>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</source>
        <translation>Giacomo Lozito &lt;city_hunter@users.sf.net&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>LADSPA Plugin Catalog</source>
        <translation>Katalog Plugin LADSPA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="59"/>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="94"/>
        <source>Configure</source>
        <translation>Tata</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Name</source>
        <translation>Nama</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>This LADSPA plugin has no user controls</source>
        <translation>Plugin LADSPA ini tidak memiliki kendali pengguna</translation>
    </message>
</context>
</TS>
